@@ -4,6 +4,7 @@ use alloc::boxed::Box;
 use alloc::string::ToString;
 use alloc::vec;
 use alloc::vec::Vec;
+use regex_automata::{Regex, SparseDFA};
 
 use crate::method::Method;
 use crate::request::Request;
@@ -12,10 +13,10 @@ use crate::uri::path::Path;
 
 type RequestHandler = Box<dyn FnMut(Request) -> Response>;
 
-#[derive(Debug, Clone, Eq, PartialEq, Ord, PartialOrd)]
+#[derive(Debug, Clone)]
 pub struct HttpRoute {
     pub method: Method,
-    pub path: Path,
+    pub path_regex: Regex<SparseDFA<Vec<u8>>>,
 }
 
 pub struct HttpRouter {
@@ -45,9 +46,9 @@ impl HttpRouter {
 
         for (route, handler) in self.routes.iter_mut() {
             if route.method == request.method
-                && request_path
-                    .to_string()
-                    .starts_with(route.path.to_string().as_str())
+                && route
+                    .path_regex
+                    .is_match(request_path.to_string().as_bytes())
             {
                 return handler(request);
             }
