@@ -5,7 +5,7 @@ use core::convert::TryFrom;
 
 use crate::error::HttpError;
 
-#[derive(Debug, Clone, Eq, PartialEq, Ord, PartialOrd)]
+#[derive(Debug, Clone, PartialEq)]
 pub struct Path {
     pub src: String,
 }
